<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Grimlock_WooCommerce_Products_Block
 *
 * @author  themosaurus
 * @package grimlock-woocommerce/inc
 */
class Grimlock_WooCommerce_Products_Block extends Grimlock_Query_Block {

	/**
	 * Setup class.
	 *
	 * @param string $type Block type
	 * @param string $domain Block domain
	 *
	 * @since 1.1.5
	 */
	public function __construct( $type = 'products', $domain = 'grimlock-woocommerce' ) {
		parent::__construct( $type, $domain );

		// Query Panel
		remove_filter( "{$this->id_base}_query_panel_fields", array( $this, 'add_post_type_field'          ), 110 );
		remove_filter( "{$this->id_base}_query_panel_fields", array( $this, 'add_handpick_posts_field'     ), 120 );
		remove_filter( "{$this->id_base}_query_panel_fields", array( $this, 'add_posts_field'              ), 130 );
		add_filter( "{$this->id_base}_query_panel_fields",    array( $this, 'add_show_only_featured_field' ), 110 );
		add_filter( "{$this->id_base}_query_panel_fields",    array( $this, 'add_show_only_on_sale_field'  ), 111 );
	}

	/**
	 * Add a select to set what products cats need to be displayed in the query
	 *
	 * @param array $fields Array of block fields
	 *
	 * @return array Modified array of block fields
	 */
	public function add_taxonomies_field( $fields ) {
		$taxonomies_choices = array();
		$terms              = get_terms( array( 'taxonomy' => 'product_cat' ) );
		$terms_choices      = array();

		if ( ! is_wp_error( $terms ) ) {
			foreach ( $terms as $term ) {
				$terms_choices['product_cat|' . $term->slug] = $term->name;
			}
		}

		$taxonomies_choices['product_cat'] = array(
			'label'      => esc_html__( 'Categories', 'grimlock-woocommerce' ),
			'subchoices' => $terms_choices,
		);

		$fields[] = $this->select_field( apply_filters( "{$this->id_base}_taxonomies_field_args", array(
			'name'     => 'taxonomies',
			'label'    => esc_html__( 'Categories', 'grimlock-woocommerce' ),
			'choices'  => $taxonomies_choices,
			'multiple' => true,
		) ) );

		return $fields;
	}

	/**
	 * Add a checkbox field to set whether the query should only return featured products
	 *
	 * @param array $fields Array of block fields
	 *
	 * @return array Modified array of block fields
	 */
	public function add_show_only_featured_field( $fields ) {
		$fields[] = $this->toggle_field( apply_filters( "{$this->id_base}_show_only_featured_field_args", array(
			'name'  => 'show_only_featured',
			'label' => esc_html__( 'Show only featured products', 'grimlock-woocommerce' ),
		) ) );

		return $fields;
	}

	/**
	 * Add a checkbox field to set whether the query should only return products on sale
	 *
	 * @param array $fields Array of block fields
	 *
	 * @return array Modified array of block fields
	 */
	public function add_show_only_on_sale_field( $fields ) {
		$fields[] = $this->toggle_field( apply_filters( "{$this->id_base}_show_only_on_sale_field_args", array(
			'name'  => 'show_only_on_sale',
			'label' => esc_html__( 'Show only products on sale', 'grimlock-woocommerce' ),
		) ) );

		return $fields;
	}

	/**
	 * Handles sanitizing attributes for the current block instance.
	 *
	 * @param array $new_attributes New attributes for the current block instance
	 *
	 * @return array Attributes to save
	 */
	public function sanitize_attributes( $new_attributes ) {
		$attributes = parent::sanitize_attributes( $new_attributes );

		$attributes['show_only_featured']       = filter_var( $new_attributes['show_only_featured'], FILTER_VALIDATE_BOOLEAN );
		$attributes['show_only_on_sale']        = filter_var( $new_attributes['show_only_on_sale'], FILTER_VALIDATE_BOOLEAN );
		$attributes['start_date']               = isset( $new_attributes['start_date'] ) ? sanitize_text_field( $new_attributes['start_date'] ) : '';
		$attributes['end_date']                 = isset( $new_attributes['end_date'] ) ? sanitize_text_field( $new_attributes['end_date'] ) : '';
		$attributes['hide_recurrences']         = isset( $new_attributes['hide_recurrences'] ) ? filter_var( $new_attributes['hide_recurrences'], FILTER_VALIDATE_BOOLEAN ) : false;

		return $attributes;
	}

	/**
	 * @param $attributes
	 *
	 * @return WC_Product_Query
	 */
	protected function make_query( $attributes ) {
		$query_args = array(
			'post_type'           => 'product',
			'posts_per_page'      => $attributes['posts_per_page'],
			'orderby'             => $attributes['orderby'],
			'order'               => $attributes['order'],
			'tax_query'           => array(),
		);

		if ( ! empty( $attributes['taxonomies'] ) ) {
			$taxonomies_terms = array();
			foreach ( $attributes['taxonomies'] as $term ) {
				$taxonomy_term = explode( '|', $term, 2 );
				if ( ! isset( $taxonomies_terms[ $taxonomy_term[0] ] ) ) {
					$taxonomies_terms[ $taxonomy_term[0] ] = array();
				}
				$taxonomies_terms[ $taxonomy_term[0] ][] = $taxonomy_term[1];
			}

			$tax_query = array();
			foreach ( $taxonomies_terms as $taxonomy => $terms ) {
				$tax_query[] = array(
					'taxonomy' => $taxonomy,
					'field'    => 'slug',
					'terms'    => $terms
				);
			}

			$query_args['tax_query'] = $tax_query;
		}

		if ( ! empty( $attributes['show_only_featured'] ) ) {
			$featured_products      = wc_get_featured_product_ids();
			$query_args['post__in'] = ! empty( $featured_products ) ? $featured_products : array( 0 );
		}

		if ( ! empty( $attributes['show_only_on_sale'] ) ) {
			$on_sale_products       = wc_get_product_ids_on_sale();
			$query_args['post__in'] = ! empty( $on_sale_products ) ? $on_sale_products : array( 0 );
		}

		if ( ! empty( $attributes['show_only_featured'] ) && ! empty( $attributes['show_only_on_sale'] ) ) {
			$featured_on_sale_products = array_intersect( $featured_products, $on_sale_products );
			$query_args['post__in']    = ! empty( $featured_on_sale_products ) ? $featured_on_sale_products : array( 0 );
		}

		if ( ! empty( $attributes['meta_key'] ) ) {
			$query_args['meta_query'] = array(
				array(
					'key'     => $attributes['meta_key'],
					'value'   => $attributes['meta_value'],
					'compare' => $attributes['meta_compare'],
					'type'    => empty( $attributes['meta_value_num'] ) ? 'CHAR' : 'NUMERIC',
				),
			);
		}

		return new WP_Query( apply_filters( "{$this->id_base}_query_args", $query_args, $attributes ) );
	}

	/**
	 * Get default field values for the block
	 *
	 * @return array Array of default field values
	 */
	public function get_defaults() {
		$defaults = parent::get_defaults();

		return array_merge( $defaults, array(
			'show_only_featured' => false,
			'show_only_on_sale'  => false,
			'posts_per_page'     => '3',
			'orderby'            => 'menu_order',
			'order'              => 'ASC',
		) );
	}

	/**
	 * Render the Gutenberg block
	 *
	 * @param $attributes
	 * @param $content
	 *
	 * @return string
	 */
	public function render_block( $attributes, $content ) {
		$attributes = $this->sanitize_attributes( $attributes );
		ob_start();
		do_action( 'grimlock_query', apply_filters( "{$this->id_base}_component_args", $this->get_component_args( $attributes ), $attributes ) );
		return ob_get_clean();
	}
}

return new Grimlock_WooCommerce_Products_Block();
