<?php
/**
 * Grimlock_WooCommerce_Single_Product_Customizer Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package grimlock
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock Customizer class for the single product.
 */
class Grimlock_WooCommerce_Single_Product_Customizer extends Grimlock_Template_Customizer {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->id      = 'single_product';
		$this->section = 'grimlock_woocommerce_single_product_customizer_section';
		$this->title   = esc_html__( 'Single Product', 'grimlock-woocommerce' );

		add_action( 'after_setup_theme',                         array( $this, 'add_customizer_fields'           ), 20    );

		add_filter( 'body_class',                                array( $this, 'add_body_classes'                ), 10, 1 );

		add_filter( 'grimlock_customizer_controls_js_data',      array( $this, 'add_customizer_controls_js_data' ), 10, 1 );
		add_filter( 'grimlock_content_class',                    array( $this, 'add_content_classes'             ), 10, 1 );
		add_filter( 'grimlock_custom_header_args',               array( $this, 'add_custom_header_args'          ), 20, 1 );
		add_filter( 'grimlock_custom_header_displayed',          array( $this, 'has_custom_header_displayed'     ), 10, 1 );
		add_filter( 'grimlock_template_sidebar_right_displayed', array( $this, 'has_sidebar_right_displayed'     ), 10, 1 );
		add_filter( 'grimlock_template_sidebar_left_displayed',  array( $this, 'has_sidebar_left_displayed'      ), 10, 1 );
		add_filter( 'grimlock_single_customizer_is_template',    array( $this, 'single_customizer_is_template'   ), 10, 1 );

		add_filter( 'kirki_grimlock_dynamic_css',                array( $this, 'add_dynamic_css'                 ), 10, 1 );
	}

	/**
	 * Add custom classes to body to modify layout.
	 *
	 * @param $classes
	 * @since 1.0.0
	 *
	 * @return string[]
	 */
	public function add_body_classes( $classes ) {
		$classes = parent::add_body_classes( $classes );

		if ( $this->is_template() && ! empty( $this->get_theme_mod( 'single_product_force_back_to_shop_displayed' ) ) ) {
			$classes[] = 'grimlock-woocommerce--single_product_force_back_to_shop_displayed';
		}

		return $classes;
	}

	/**
	 * Add arguments using theme mods to customize the Custom Header.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args The default arguments to render the Custom Header.
	 *
	 * @return array      The arguments to render the Custom Header.
	 */
	public function add_custom_header_args( $args ) {
		$args = parent::add_custom_header_args( $args );

		if ( $this->is_template() ) {
			$args['background_image'] = get_header_image();
			$shop_page                = get_post( get_option( 'woocommerce_shop_page_id' ) );

			if ( ! empty( $shop_page ) && $shop_page instanceof WP_Post ) {
				$args['title']            = get_the_title( $shop_page->ID );
				$args['subtitle']         = "<span class='excerpt'>{$shop_page->post_excerpt}</span>";

				$shop_page_thumbnail_id   = get_post_thumbnail_id( $shop_page->ID );
				$shop_page_thumbnail_atts = ! empty( $shop_page_thumbnail_id ) ? wp_get_attachment_image_src( $shop_page_thumbnail_id, 'custom-header' ) : false;

				if ( ! empty( $shop_page_thumbnail_atts[0] ) ) {
					$args['background_image'] = $shop_page_thumbnail_atts[0];
				}
			}
		}
		return $args;
	}

	/**
	 * Add tabs to the Customizer to group controls.
	 *
	 * @param  array $js_data The array of data for the Customizer controls.
	 *
	 * @return array          The filtered array of data for the Customizer controls.
	 */
	public function add_customizer_controls_js_data( $js_data ) {
		$js_data['tabs'][$this->section] = array(
			array(
				'label' => esc_html__( 'Layout', 'grimlock-woocommerce' ),
				'class' => 'single_product-layout-tab',
				'controls' => array(
					'single_product_layout',
					'single_product_sidebar_mobile_displayed',
					"{$this->section}_divider_30",
					'single_product_container_layout',
					'single_product_force_back_to_shop_displayed',
				),
			),
			array(
				'label' => esc_html__( 'Style', 'grimlock-woocommerce' ),
				'class' => 'single_product-style-tab',
				'controls' => array(
					'single_product_content_padding_y',
				),
			),
		);
		return $js_data;
	}

	/**
	 * Check if the current template is the expected template.
	 *
	 * @since 1.0.0
	 *
	 * @return bool True when the template is the expected template, false otherwise.
	 */
	protected function is_template() {
		$is_template = is_singular( 'product' );
		return apply_filters( 'grimlock_woocommerce_single_product_customizer_is_template', $is_template );
	}

	/**
	 * Disinherit single customizer settings
	 *
	 * @param bool $default True if we are on a default single page
	 *
	 * @return bool
	 */
	public function single_customizer_is_template( $default ) {
		return $default && ! $this->is_template();
	}

	/**
	 * Register default values, settings and custom controls for the Theme Customizer.
	 *
	 * @since 1.0.0
	 */
	public function add_customizer_fields() {
		$this->defaults = apply_filters( 'grimlock_woocommerce_single_product_customizer_defaults', array(
			'single_product_custom_header_displayed'       => false,

			'single_product_force_back_to_shop_displayed'  => false,

			'single_product_layout'                        => '12-cols-left',
			'single_product_sidebar_mobile_displayed'      => true,
			'single_product_container_layout'              => 'classic',

			'single_product_content_padding_y'             => GRIMLOCK_CONTENT_PADDING_Y,
		) );

		$this->add_section();


		$this->add_layout_field(                       array( 'priority' => 10 ) );
		$this->add_sidebar_mobile_displayed_field(     array( 'priority' => 20 ) );
		$this->add_divider_field(                      array( 'priority' => 30 ) );
		$this->add_container_layout_field(             array( 'priority' => 30 ) );
		$this->add_force_back_to_shop_displayed_field( array( 'priority' => 40  ) );

		$this->add_content_padding_y_field(            array( 'priority' => 100 ) );
	}

	/**
	 * Add a Kirki checkbox to set the back to shop display when there is already a breadcrumb.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_force_back_to_shop_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'            => 'checkbox',
				'section'         => $this->section,
				'label'           => esc_html__( 'Display "Back to Shop" link instead of the breadcrumb ?', 'grimlock-woocommerce' ),
				'settings'        => "{$this->id}_force_back_to_shop_displayed",
				'default'         => $this->get_default( "{$this->id}_force_back_to_shop_displayed" ),
				'priority'        => 10,
				'active_callback' => array(
					array(
						'setting'  => 'breadcrumb_custom_header_displayed',
						'operator' => '==',
						'value'    => true,
					),
				),
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_{$this->id}_customizer_force_back_to_shop_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki section in the Customizer.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args
	 */
	protected function add_section( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			Kirki::add_section( $this->section, apply_filters( "{$this->section}_args", array(
				'title'    => $this->title,
				'priority' => 30,
				'panel'    => 'woocommerce',
			) ) );
		}
	}
}

return new Grimlock_WooCommerce_Single_Product_Customizer();
