<?php
/**
 * Grimlock WooCommerce template functions for WooCommerce.
 *
 * @package grimlock-woocommerce
 */

/**
 * Ensure cart contents update when products are added to the cart via AJAX
 *
 * @param  array $fragments Fragments to refresh via AJAX.
 * @return array            Fragments to refresh via AJAX
 */
function grimlock_woocommerce_cart_link_fragment( $fragments ) {
	ob_start();
	grimlock_woocommerce_cart_link( true );
	$fragments['a.cart-contents > div'] = ob_get_clean();

	return $fragments;
}

/**
 * Displayed a link to the cart including the number of items present and the cart total
 */
function grimlock_woocommerce_cart_link( $is_fragment = false ) {
	if ( function_exists( 'WC' ) && function_exists( 'wc_get_cart_url' ) ) : ?>
		<?php if ( ! $is_fragment ) : ?>
			<a class="cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'grimlock-woocommerce' ); ?>">
		<?php endif; ?>

		<div>
			<span class="cart-icon"></span>
			<span class="bubble-count" data-count="<?php echo WC()->cart->get_cart_contents_count(); ?>">
				<?php echo WC()->cart->get_cart_contents_count(); ?>
			</span>
			<span class="amount"><?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></span> <span class="count"><?php echo wp_kses_data( sprintf( _n( '%d item', '%d items', WC()->cart->get_cart_contents_count(), 'grimlock-woocommerce' ), WC()->cart->get_cart_contents_count() ) );?></span>
		</div>

		<?php if ( ! $is_fragment ) : ?>
			</a>
		<?php endif; ?>
	<?php
	endif;
}

/**
 * Prints HTML for the product template
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_product_template( $args ) {
	add_filter( 'grimlock_woocommerce_product_args', 'grimlock_woocommerce_query_product_args', 20 );
	wc_get_template_part( 'content', 'product' );
	remove_filter( 'grimlock_woocommerce_product_args', 'grimlock_woocommerce_query_product_args', 20 );
}

/**
 * Add product args specific to grimlock query
 *
 * @param array $args
 *
 * @return array
 */
function grimlock_woocommerce_query_product_args( $args ) {
	$args['remove_li'] = true;

	return $args;
}

/**
 * Prints HTML for the checkout order heading
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_order_review_heading( $args ) {
	?>
	<h3 id="order_review_heading"><?php esc_html_e( 'Your order', 'woocommerce' ); ?></h3>
	<?php
}

/**
 * Prints HTML for the product out of stock badge for Grimlock WC component
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_product_out_of_stock( $args ) {
	if ( ! empty( $args['product_out_of_stock_displayed'] ) && function_exists( 'wc_get_product' ) ) {
		$product = wc_get_product( get_the_ID() );

		if ( ! empty( $product ) && ! $product->is_in_stock() ) :
			$availability = $product->get_availability(); ?>
			<span class="<?php echo esc_attr( $availability['class'] ); ?>"><?php echo esc_html( $availability['availability'] ); ?></span>
		<?php endif;
	}
}

/**
 * Prints HTML for the product add to cart button for WC product item template
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_product_after_shop_loop_item() { ?>
	<div class="product-buttons">
		<?php
		/**
		 * Hook: woocommerce_after_shop_loop_item.
		 *
		 * @hooked woocommerce_template_loop_add_to_cart - 10
		 */
		do_action( 'woocommerce_after_shop_loop_item' );
		?>
	</div><!-- .product__buttons -->
	<?php
}

/**
 * Prints background image for grid layout in product cats.
 *
 * @param object $category The object of the product category.
 */
function grimlock_woocommerce_content_product_cat_background_image( $category ) {
	if ( apply_filters( 'grimlock_woocommerce_content_product_cat_layout', 'layout_default' ) === 'layout_grid' ) {
		$thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true );
		$image_url    = wp_get_attachment_url( $thumbnail_id );
		if ( $image_url ) /* translators: %s: URL for the background image */ {
			printf( 'style="background-image:url(%s)"', esc_url( $image_url ) );
		}
	}
}

/**
 * Output the start of the page wrapper.
 */
function grimlock_woocommerce_output_content_wrapper() {
	get_sidebar( 'left' ); ?>
	<div id="primary" class="content-area region__col region__col--2">
		<main id="main" class="site-main">
	<?php
}

/**
 * Output the end of the page wrapper.
 */
function grimlock_woocommerce_output_content_wrapper_end() {
	?>
		</main><!-- #main -->
	</div><!-- #primary -->
	<?php
	get_sidebar( 'right' );
}

/**
 * Display the WooCommerce cart widget
 */
function grimlock_woocommerce_cart_widget() {
	if ( class_exists( 'WC_Widget_Cart' ) ) :
		the_widget( 'WC_Widget_Cart', 'title=' );
	endif;
}

/**
 * Display content before shop archives main content
 */
function grimlock_woocommerce_before_main_content() { ?>

	<header class="grimlock--page-header entry-header">

		<?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>

			<h1 class="page-title entry-title page-title"><?php woocommerce_page_title(); ?></h1>

			<?php
			do_action( 'grimlock_woocommerce_breadcrumb' );

		endif;

		if ( is_singular('product') ): ?>

			<div class="single-post-back wc-product-back">
				<a href="<?php echo esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ); ?>">
					<?php esc_html_e( 'Back to shop', 'grimlock-woocommerce' ); ?>
				</a>
				<span class="single-post-back__active"><?php the_title(); ?></span>
			</div> <!-- .single-post-back -->

		<?php
		endif; ?>

	</header>

	<?php
	/**
	 * Hook: woocommerce_archive_description.
	 *
	 * @hooked woocommerce_taxonomy_archive_description - 10
	 * @hooked woocommerce_product_archive_description - 10
	 */
	do_action( 'woocommerce_archive_description' ); ?>

<?php }

/**
 * Display content before archives shop loop
 */
function grimlock_woocommerce_before_shop_loop() { ?>

	<div class="woocommerce-archive-header">

		<div class="woocommerce-archive-header_result_count mr-md-auto d-none d-md-block">
			<?php woocommerce_result_count(); ?>
		</div> <!-- woocommerce-archive-header_result_count -->

		<div class="woocommerce-archive-header__catalog_ordering mr-auto mr-md-0 pr-3 pr-md-0">
			<?php woocommerce_catalog_ordering(); ?>
		</div> <!-- woocommerce-archive-header__catalog_ordering -->

		<?php if ( is_active_sidebar( 'wc-filters-sidebar' ) ) : ?>

			<div class="woocommerce-archive-header__catalog_filters dropdown dropdown-wc-filters ml-md-4" id="dropdown-wc-filters">

					<a class="dropdown-toggle" id="dropdownWcFiltersButton" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
						<?php esc_html_e( 'Filter', 'grimlock-woocommerce' ); ?>
					</a>

					<div class="dropdown-menu" aria-labelledby="dropdownWcFiltersButton">
						<aside id="woocommerce-filters" class="widget-area sidebar sidebar--woocommerce-filters">
							<?php dynamic_sidebar( 'wc-filters-sidebar' ); ?>
						</aside> <!-- #secondary-right -->
					</div> <!-- dropdown-menu -->

				<div class="dropdown-backdrop element-animated fade-in super-short"></div>

			</div> <!-- woocommerce-archive-header__catalog_filters -->

		<?php endif; ?>

	</div> <!-- woocommerce-archive-header -->

<?php }

/**
 * Prints HTML for the product categories
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_category_list( $args ) {
	if ( 'product' === get_post_type() && function_exists( 'wc_get_product_category_list' ) && ! empty( $args['product_category_displayed'] ) ) :
		/* translators: used between list items, there is a space after the comma */
		$categories_list = wc_get_product_category_list( get_the_ID(), '<span class="cat-links-separator">' . esc_html__( ', ', 'grimlock-woocommerce' ) . '</span>' );
		if ( $categories_list ) {
			printf( '<span class="cat-links"><span class="cat-links-label">' . esc_html__( 'Posted in', 'grimlock-woocommerce' ) . ' </span>%1$s </span>', $categories_list ); // WPCS: XSS OK.
		}
	endif;
}

/**
 * Prints HTML for WC dashboard
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_dashboard( $args ) { ?>
	<div class="row wc-dashboard-cards pt-3">
		<div class="col-12 col-sm-6 col-md my-2 m-md-0">
			<div class="wc-dashboard-card wc-dashboard-card--shop">
				<a href="<?php echo wc_get_cart_url() ?>">
					<?php esc_html_e( 'Cart', 'woocommerce' ); ?>
				</a>
			</div>
		</div>
		<div class="col-12 col-sm-6 col-md my-2 m-md-0">
			<div class="wc-dashboard-card wc-dashboard-card--orders">
				<a href="<?php echo esc_url( wc_get_endpoint_url( 'orders' ) ); ?>">
					<?php esc_html_e( 'Orders', 'woocommerce' ); ?>
				</a>
			</div>
		</div>
		<div class="col-12 col-sm-6 col-md my-2 m-md-0">
			<div class="wc-dashboard-card wc-dashboard-card--address">
				<a href="<?php echo esc_url( wc_get_endpoint_url( 'edit-address' ) ); ?>">
					<?php esc_html_e( 'Addresses', 'woocommerce' ); ?>
				</a>
			</div>
		</div>
		<div class="col-12 col-sm-6 col-md my-2 m-md-0">
			<div class="wc-dashboard-card wc-dashboard-card--edit">
				<a href="<?php echo esc_url( wc_get_endpoint_url( 'edit-account' ) ); ?>">
					<?php esc_html_e( 'Account details', 'woocommerce' ); ?>
				</a>
			</div>
		</div>
	</div>
<?php }


/**
 * Prints HTML for WC single title wrapper - Before
 */

function grimlock_woocommerce_single_title_before() { ?>
	<div class="product-title-wrapper">
<?php }

/**
 * Prints HTML for WC single title wrapper - After
 */

function grimlock_woocommerce_single_title_after() { ?>
	</div>
<?php }


/**
 * Prints HTML for WC single title wrapper - Open
 */

function grimlock_woocommerce_single_product_summary_open() { ?>
	<div class="product-summary-wrapper clearfix">
<?php }

/**
 * Prints HTML for WC single title wrapper - Close
 */

function grimlock_woocommerce_single_product_summary_close() { ?>
	</div>
	<div class="product-after-summary-wrapper clearfix">
<?php }

/**
 * Prints HTML for WC single title wrapper - Close
 */

function grimlock_woocommerce_after_single_product_summary_close() { ?>
	</div>
<?php }

/**
 * Prints HTML for the wpc brand thumbnail
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_wpc_brand_thumbnail( $args ) {
	if ( ! empty( $args['term_thumbnail_displayed'] ) && function_exists( 'get_term_meta' ) && get_term( $args['term_id'] )->taxonomy === 'wpc-brand' ) :
		$thumbnail_id = get_term_meta( $args['term_id'], 'wpcbr_banner', true );
		if ( ! empty( $thumbnail_id ) ) : ?>
			<div class="card-img">
				<a href="<?php echo esc_url( get_term_link( $args['term_id'] ) ); ?>" title="<?php echo $args['name']; ?>" rel="bookmark">
					<?php echo wp_get_attachment_image( $thumbnail_id, $args['term_thumbnail_size'], false, $args['term_thumbnail_attr'] ); ?>
				</a>
			</div>
		<?php
		endif;
	endif;
}

/**
 * Prints HTML for the wpc brand logo
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_wpc_brand_logo( $args ) {
	if ( ! empty( $args['term_thumbnail_displayed'] ) && function_exists( 'get_term_meta' ) && get_term( $args['term_id'] )->taxonomy === 'wpc-brand' ) :
		$thumbnail_id = get_term_meta( $args['term_id'], 'wpcbr_logo', true );
		if ( ! empty( $thumbnail_id ) ) : ?>
			<div class="grimlock--term-logo">
				<?php echo wp_get_attachment_image( $thumbnail_id, $args['term_thumbnail_size'], false, $args['term_thumbnail_attr'] ); ?>
			</div>
		<?php
		endif;
	endif;
}
